@@ -1,4 +1,6 @@
+import asyncio
 import contextlib
+import threading
 from typing import Dict, Any
 
 from contextvars import ContextVar
@@ -10,6 +12,7 @@ class ContextData(object):
             for name, value in props.items():
                 super().__setattr__(name, self._wrap(value))
         super().__setattr__('data', kwargs)
+        self._id = None
 
     def _wrap(self, value):
         if isinstance(value, (tuple, list, set, frozenset)):
@@ -20,6 +23,22 @@ class ContextData(object):
     def __setattr__(self, key, value):
         super().__setattr__(key, self._wrap(value))
 
+    def __contains__(self, item):
+        return item in self.__dict__
+
+    @property
+    def session_id(self):
+        if self._id:
+            return self._id
+        try:
+            return id(asyncio.current_task())
+        except RuntimeError:
+            return threading.current_thread().ident
+
+    @session_id.setter
+    def session_id(self, value):
+        self._id = value
+
 
 _ctx: ContextVar[ContextData] = ContextVar('_ctx')
 
@@ -32,7 +51,12 @@ def get_context():
 
 
 @contextlib.contextmanager
-def with_context():
+def with_context(force_new: bool = False):
+    if not force_new:
+        if ctx := _ctx.get(None):
+            yield ctx
+            return
+
     token = _ctx.set(ContextData())
-    yield
+    yield _ctx.get(None)
     _ctx.reset(token)
