@@ -1,6 +1,6 @@
-from typing import Protocol, Any, Optional, List, Tuple, Union
+from typing import Any, Optional, Protocol, Sequence, Tuple, Union
 
-from dropland.engines.base import SyncEngine, AsyncEngine
+from dropland.engines.base import AsyncEngine, SyncEngine
 
 
 class ModelProtocol(Protocol):
@@ -20,7 +20,7 @@ class ModelProtocol(Protocol):
         ...
 
     @classmethod
-    async def get_any(cls, indices: List[Any], **kwargs) -> List[Optional['ModelProtocol']]:
+    async def get_any(cls, indices: Sequence[Any], **kwargs) -> Sequence[Optional['ModelProtocol']]:
         ...
 
     @classmethod
@@ -36,7 +36,7 @@ class ModelProtocol(Protocol):
         ...
 
     @classmethod
-    async def get_or_create(cls, id_value: Any, data:Any, **kwargs) -> Tuple[Optional['ModelProtocol'], bool]:
+    async def get_or_create(cls, id_value: Any, data: Any, **kwargs) -> Tuple[Optional['ModelProtocol'], bool]:
         ...
 
     async def update(self, data: Any) -> bool:
@@ -49,18 +49,18 @@ class ModelProtocol(Protocol):
     async def save(self, *args, **kwargs) -> bool:
         ...
 
-    async def load(self, field_names: List[str] = None) -> bool:
+    async def load(self, field_names: Sequence[str] = None) -> bool:
         ...
 
     @classmethod
-    async def save_all(cls, objects: List['ModelProtocol'], *args, **kwargs) -> bool:
+    async def save_all(cls, objects: Sequence['ModelProtocol'], *args, **kwargs) -> bool:
         ...
 
     async def delete(self) -> bool:
         ...
 
     @classmethod
-    async def delete_all(cls, indices: List[Any] = None) -> bool:
+    async def delete_all(cls, indices: Sequence[Any] = None) -> bool:
         ...
 
     @classmethod
