@@ -3,7 +3,7 @@ from typing import Any, Dict, Union
 from starlette.exceptions import HTTPException
 from starlette.status import HTTP_404_NOT_FOUND
 
-from dropland.blocks.sql.model import UpdateSchemaType
+from dropland.engines.sqla.model import UpdateSchemaType
 
 
 # noinspection PyUnresolvedReferences
